Learn R Programming

miceadds (version 2.2-0)

grep.vec: R Utilities: Vector Based Version of grep

Description

This function imitates the usage of grep but it is extended to a vector argument.

Usage

grep.vec(pattern.vec, x, operator="AND")

Arguments

pattern.vec
String which should be looked for in vector x
x
A character vector
operator
An optional string. The default argument "AND" searches all entries in x which contain all elements of pattern.vec. If operator is different from the default, then the "OR" logic applies, i.e. the functions searches for vector entries which contain at least one of the strings in pattern.vec.

Examples

Run this code
vec <- c("abcd" , "bcde" , "aedf" , "cdf" )
# search for entries in vec with contain 'a' and 'f'
#  -> operator = "AND"
grep.vec( pattern.vec=c("a","f") , x=vec )
  ##   $x
  ##   [1] "aedf"
  ##   $index.x
  ##   [1] 3

# search for entries in vec which contain 'a' or 'f'
grep.vec( pattern.vec=c("a","f") , x=vec , operator="OR")
  ##   $x
  ##   [1] "abcd" "aedf" "cdf" 
  ##   $index.x
  ##   [1] 1 3 4

Run the code above in your browser using DataLab