Learn R Programming

miceadds (version 2.2-0)

library_install: R Utilities: Loading a Package or Installation of a Package if Necessary

Description

Loads packages specified in vector pkg. If some packages are not yet installed, they will be automatically installed by this function using install.packages.

Usage

library_install( pkg , ... )

Arguments

pkg
Vector with package names
...
Further arguments to be passed to install.packages

Examples

Run this code
## Not run: 
# # try to load packages PP and MCMCglmm
# library_install( pkg =  c("PP" , "MCMCglmm") )   
# ## End(Not run)	

Run the code above in your browser using DataLab